You are viewing a plain text version of this content. The canonical link for it is here.
Posted to derby-commits@db.apache.org by dj...@apache.org on 2005/02/02 21:48:15 UTC

svn commit: r151052 - in incubator/derby/code/trunk/java: drda/org/apache/derby/impl/drda/ engine/org/apache/derby/iapi/jdbc/ engine/org/apache/derby/iapi/reference/ engine/org/apache/derby/iapi/services/i18n/ engine/org/apache/derby/iapi/services/info/ engine/org/apache/derby/iapi/types/ engine/org/apache/derby/impl/db/ engine/org/apache/derby/impl/io/ engine/org/apache/derby/impl/services/jce/ engine/org/apache/derby/impl/services/monitor/ engine/org/apache/derby/impl/services/reflect/ engine/org/apache/derby/impl/sql/compile/ engine/org/apache/derby/jdbc/ engine/org/apache/derby/loc/ tools/org/apache/derby/impl/tools/sysinfo/ tools/org/apache/derby/tools/

Author: djd
Date: Wed Feb  2 12:48:12 2005
New Revision: 151052

URL: http://svn.apache.org/viewcvs?view=rev&rev=151052
Log:
Add constants to represent the values for JVMInfo.JDK_ID.
Add sysinfo output for Derb'y understanding of the JVM level.
Add initial support for detecting a J2ME environment.
Clean up some old JDK 1.1 support code.

Modified:
    incubator/derby/code/trunk/java/drda/org/apache/derby/impl/drda/DB2jServerImpl.java
    incubator/derby/code/trunk/java/engine/org/apache/derby/iapi/jdbc/BrokeredStatement.java
    incubator/derby/code/trunk/java/engine/org/apache/derby/iapi/reference/SQLState.java
    incubator/derby/code/trunk/java/engine/org/apache/derby/iapi/services/i18n/MessageService.java
    incubator/derby/code/trunk/java/engine/org/apache/derby/iapi/services/info/JVMInfo.java
    incubator/derby/code/trunk/java/engine/org/apache/derby/iapi/types/SQLDecimal.java
    incubator/derby/code/trunk/java/engine/org/apache/derby/iapi/types/SQLSmallint.java
    incubator/derby/code/trunk/java/engine/org/apache/derby/impl/db/BasicDatabase.java
    incubator/derby/code/trunk/java/engine/org/apache/derby/impl/io/DirStorageFactory4.java
    incubator/derby/code/trunk/java/engine/org/apache/derby/impl/services/jce/JCECipherFactory.java
    incubator/derby/code/trunk/java/engine/org/apache/derby/impl/services/monitor/BaseMonitor.java
    incubator/derby/code/trunk/java/engine/org/apache/derby/impl/services/reflect/JarLoader.java
    incubator/derby/code/trunk/java/engine/org/apache/derby/impl/sql/compile/FromVTI.java
    incubator/derby/code/trunk/java/engine/org/apache/derby/jdbc/EmbedXAConnection.java
    incubator/derby/code/trunk/java/engine/org/apache/derby/jdbc/ResourceAdapterImpl.java
    incubator/derby/code/trunk/java/engine/org/apache/derby/loc/messages_en.properties
    incubator/derby/code/trunk/java/tools/org/apache/derby/impl/tools/sysinfo/Main.java
    incubator/derby/code/trunk/java/tools/org/apache/derby/tools/ij.java

Modified: incubator/derby/code/trunk/java/drda/org/apache/derby/impl/drda/DB2jServerImpl.java
URL: http://svn.apache.org/viewcvs/incubator/derby/code/trunk/java/drda/org/apache/derby/impl/drda/DB2jServerImpl.java?view=diff&r1=151051&r2=151052
==============================================================================
--- incubator/derby/code/trunk/java/drda/org/apache/derby/impl/drda/DB2jServerImpl.java (original)
+++ incubator/derby/code/trunk/java/drda/org/apache/derby/impl/drda/DB2jServerImpl.java Wed Feb  2 12:48:12 2005
@@ -2073,7 +2073,7 @@
 										// socket with 0.0.0.0 (all addresses) so we will
 										// getLocalHost() which will suffice.
 										InetAddress connectAddress;
-										if (JVMInfo.JDK_ID < 4 &&
+										if (JVMInfo.JDK_ID <= JVMInfo.J2SE_13 &&
 											hostAddress.getHostAddress().equals("0.0.0.0"))
 											connectAddress = InetAddress.getLocalHost();
 										else

Modified: incubator/derby/code/trunk/java/engine/org/apache/derby/iapi/jdbc/BrokeredStatement.java
URL: http://svn.apache.org/viewcvs/incubator/derby/code/trunk/java/engine/org/apache/derby/iapi/jdbc/BrokeredStatement.java?view=diff&r1=151051&r2=151052
==============================================================================
--- incubator/derby/code/trunk/java/engine/org/apache/derby/iapi/jdbc/BrokeredStatement.java (original)
+++ incubator/derby/code/trunk/java/engine/org/apache/derby/iapi/jdbc/BrokeredStatement.java Wed Feb  2 12:48:12 2005
@@ -24,7 +24,7 @@
 
 import org.apache.derby.iapi.error.StandardException;
 import org.apache.derby.iapi.error.PublicAPI;
-
+import org.apache.derby.iapi.services.info.JVMInfo;
 import java.sql.Connection;
 import java.sql.ResultSet;
 import java.sql.SQLException;
@@ -465,7 +465,7 @@
         throws SQLException
 	{
 		int defaultHoldability = JDBC30Translation.HOLD_CURSORS_OVER_COMMIT;
-		if (org.apache.derby.iapi.services.info.JVMInfo.JDK_ID > 2) { //No need to use reflection for jdks 1.4 and higher
+		if (JVMInfo.JDK_ID >= JVMInfo.J2SE_14) { //No need to use reflection for jdks 1.4 and higher
 			defaultHoldability = getStatement().getResultSetHoldability();
 		} else {
 			try {

Modified: incubator/derby/code/trunk/java/engine/org/apache/derby/iapi/reference/SQLState.java
URL: http://svn.apache.org/viewcvs/incubator/derby/code/trunk/java/engine/org/apache/derby/iapi/reference/SQLState.java?view=diff&r1=151051&r2=151052
==============================================================================
--- incubator/derby/code/trunk/java/engine/org/apache/derby/iapi/reference/SQLState.java (original)
+++ incubator/derby/code/trunk/java/engine/org/apache/derby/iapi/reference/SQLState.java Wed Feb  2 12:48:12 2005
@@ -961,7 +961,6 @@
     String LANG_MULTIPLE_CONSTRAINTS_WITH_SAME_COLUMNS                 = "42Z93";
 	// String LANG_ALTER_SYSTEM_TABLE_ATTEMPTED                            = "42Z94"; -- replaced by 42X62
 	// String LANG_ALTER_TABLE_ON_NON_TABLE                                = "42Z95"; -- replaced by 42Y62
-	String LANG_RW_VTI_JAVA11										   = "42Z96";
 	String LANG_RENAME_COLUMN_WILL_BREAK_CHECK_CONSTRAINT              = "42Z97";
 	// beetle 2758.  For now just raise an error for literals > 64K
 	String LANG_INVALID_LITERAL_LENGTH                                 = "42Z99";

Modified: incubator/derby/code/trunk/java/engine/org/apache/derby/iapi/services/i18n/MessageService.java
URL: http://svn.apache.org/viewcvs/incubator/derby/code/trunk/java/engine/org/apache/derby/iapi/services/i18n/MessageService.java?view=diff&r1=151051&r2=151052
==============================================================================
--- incubator/derby/code/trunk/java/engine/org/apache/derby/iapi/services/i18n/MessageService.java (original)
+++ incubator/derby/code/trunk/java/engine/org/apache/derby/iapi/services/i18n/MessageService.java Wed Feb  2 12:48:12 2005
@@ -241,18 +241,7 @@
 
 		if (arguments == null)
 			arguments = new Object[0];
- 		else if (JVMInfo.JDK_ID == 1)
-		{
-			// make sure the Object array contains only string because in
-			// pre-116 JVMs, MessageFormat.format has a bug which cause it to
-			// output a string to System.out whenever it sees an object it
-			// can't recognize, instead of calling toString().
-			for (int i = 0; i < arguments.length; i++)
-			{
-				if (arguments[i] != null)
-					arguments[i] = arguments[i].toString();
-			}
-		}
+
 		if (bundle != null) {
 
 			try {

Modified: incubator/derby/code/trunk/java/engine/org/apache/derby/iapi/services/info/JVMInfo.java
URL: http://svn.apache.org/viewcvs/incubator/derby/code/trunk/java/engine/org/apache/derby/iapi/services/info/JVMInfo.java?view=diff&r1=151051&r2=151052
==============================================================================
--- incubator/derby/code/trunk/java/engine/org/apache/derby/iapi/types/SQLDecimal.java (original)
+++ incubator/derby/code/trunk/java/engine/org/apache/derby/iapi/types/SQLDecimal.java Wed Feb  2 12:48:12 2005
@@ -312,7 +312,7 @@
 		BigDecimal localValue = getBigDecimal();
 		if (localValue == null)
 			return null;
-		else if (JVMInfo.JDK_ID < 6)
+		else if (JVMInfo.JDK_ID < JVMInfo.J2SE_15)
 			return localValue.toString();
         else
         {

Modified: incubator/derby/code/trunk/java/engine/org/apache/derby/iapi/types/SQLSmallint.java
URL: http://svn.apache.org/viewcvs/incubator/derby/code/trunk/java/engine/org/apache/derby/iapi/types/SQLSmallint.java?view=diff&r1=151051&r2=151052
==============================================================================
--- incubator/derby/code/trunk/java/engine/org/apache/derby/iapi/types/SQLSmallint.java (original)
+++ incubator/derby/code/trunk/java/engine/org/apache/derby/iapi/types/SQLSmallint.java Wed Feb  2 12:48:12 2005
@@ -293,9 +293,7 @@
 			value = resultSet.getShort(colNumber);
 			isnull = (isNullable && resultSet.wasNull());
 		} catch (SQLException selq) {
-			System.out.println("GET SHORT " + selq.toString());
 			int i = resultSet.getInt(colNumber);
-			System.out.println("GET SHORT VALUE " + i);
 			value = (short) i;
 			isnull = false;
 

Modified: incubator/derby/code/trunk/java/engine/org/apache/derby/impl/db/BasicDatabase.java
URL: http://svn.apache.org/viewcvs/incubator/derby/code/trunk/java/engine/org/apache/derby/impl/db/BasicDatabase.java?view=diff&r1=151051&r2=151052
==============================================================================
--- incubator/derby/code/trunk/java/engine/org/apache/derby/impl/db/BasicDatabase.java (original)
+++ incubator/derby/code/trunk/java/engine/org/apache/derby/impl/db/BasicDatabase.java Wed Feb  2 12:48:12 2005
@@ -773,22 +773,19 @@
 		// classes were missing, and continue without it.
 		// Done this way to work around Chai's need to preload
 		// classes.
-		if (JVMInfo.JDK_ID >= 2)
+		// Assume both of these classes are in the class path.
+		// Assume we may need a ResourceAdapter since we don't know how
+		// this database is going to be used.
+		try
 		{
-			// If we got here, both of these classes are in the class path.
-			// Assume we may need a ResourceAdapter since we don't know how
-			// this database is going to be used.
-			try
-			{
-				resourceAdapter = 
-					Monitor.bootServiceModule(create, this,
-											 org.apache.derby.iapi.reference.Module.ResourceAdapter,
-											 allParams);
-			}
-			catch (StandardException mse)
-			{
-				// OK, resourceAdapter is an optional module
-			}
+			resourceAdapter = 
+				Monitor.bootServiceModule(create, this,
+										 org.apache.derby.iapi.reference.Module.ResourceAdapter,
+										 allParams);
+		}
+		catch (StandardException mse)
+		{
+			// OK, resourceAdapter is an optional module
 		}
 	}
 

Modified: incubator/derby/code/trunk/java/engine/org/apache/derby/impl/io/DirStorageFactory4.java
URL: http://svn.apache.org/viewcvs/incubator/derby/code/trunk/java/engine/org/apache/derby/impl/io/DirStorageFactory4.java?view=diff&r1=151051&r2=151052
==============================================================================
--- incubator/derby/code/trunk/java/engine/org/apache/derby/impl/io/DirStorageFactory4.java (original)
+++ incubator/derby/code/trunk/java/engine/org/apache/derby/impl/io/DirStorageFactory4.java Wed Feb  2 12:48:12 2005
@@ -32,7 +32,7 @@
 public class DirStorageFactory4 extends DirStorageFactory
 {
 
-	private static final boolean	rwsOK = JVMInfo.JDK_ID >= 5;
+	private static final boolean	rwsOK = JVMInfo.JDK_ID >= JVMInfo.J2SE_142;
     
     /**
      * Most of the initialization is done in the init method.

Modified: incubator/derby/code/trunk/java/engine/org/apache/derby/impl/services/jce/JCECipherFactory.java
URL: http://svn.apache.org/viewcvs/incubator/derby/code/trunk/java/engine/org/apache/derby/impl/services/jce/JCECipherFactory.java?view=diff&r1=151051&r2=151052
==============================================================================
--- incubator/derby/code/trunk/java/engine/org/apache/derby/impl/services/jce/JCECipherFactory.java (original)
+++ incubator/derby/code/trunk/java/engine/org/apache/derby/impl/services/jce/JCECipherFactory.java Wed Feb  2 12:48:12 2005
@@ -376,11 +376,6 @@
 		throws StandardException
 	{
 
-		if (SanityManager.DEBUG) {
-			if (JVMInfo.JDK_ID < 2)
-				SanityManager.THROWASSERT("expected JDK ID to be 2 - is " + JVMInfo.JDK_ID);
-		}
-
         boolean provider_or_algo_specified = false;
 		boolean storeProperties = create;
 
@@ -394,7 +389,7 @@
 		if (cryptoProvider == null)
 		{
 			// JDK 1.3 does not create providers by itself.
-			if (JVMInfo.JDK_ID == 2) {
+			if (JVMInfo.JDK_ID == JVMInfo.J2SE_13) {
 
 				String vendor;
 				try {

Modified: incubator/derby/code/trunk/java/engine/org/apache/derby/impl/services/monitor/BaseMonitor.java
URL: http://svn.apache.org/viewcvs/incubator/derby/code/trunk/java/engine/org/apache/derby/impl/services/monitor/BaseMonitor.java?view=diff&r1=151051&r2=151052
==============================================================================
--- incubator/derby/code/trunk/java/engine/org/apache/derby/impl/services/monitor/BaseMonitor.java (original)
+++ incubator/derby/code/trunk/java/engine/org/apache/derby/impl/services/monitor/BaseMonitor.java Wed Feb  2 12:48:12 2005
@@ -1666,7 +1666,7 @@
     private static final HashMap storageFactories = new HashMap();
     static {
 		String dirStorageFactoryClass;
-		if( JVMInfo.JDK_ID >= 4)
+		if( JVMInfo.JDK_ID >= JVMInfo.J2SE_14)
             dirStorageFactoryClass = "org.apache.derby.impl.io.DirStorageFactory4";
         else
             dirStorageFactoryClass = "org.apache.derby.impl.io.DirStorageFactory";

Modified: incubator/derby/code/trunk/java/engine/org/apache/derby/impl/services/reflect/JarLoader.java
URL: http://svn.apache.org/viewcvs/incubator/derby/code/trunk/java/engine/org/apache/derby/impl/services/reflect/JarLoader.java?view=diff&r1=151051&r2=151052
==============================================================================
--- incubator/derby/code/trunk/java/engine/org/apache/derby/impl/services/reflect/JarLoader.java (original)
+++ incubator/derby/code/trunk/java/engine/org/apache/derby/impl/services/reflect/JarLoader.java Wed Feb  2 12:48:12 2005
@@ -32,12 +32,10 @@
 import java.util.zip.ZipInputStream;
 import java.util.zip.ZipEntry;
 
-import java.sql.*;
+
 import org.apache.derby.iapi.services.io.LimitInputStream;
 import org.apache.derby.iapi.util.IdUtil;
 
-import org.apache.derby.iapi.services.info.JVMInfo;
-
 import org.apache.derby.iapi.reference.MessageId;
 import org.apache.derby.iapi.services.i18n.MessageService;
 
@@ -47,20 +45,9 @@
 	private static final JarFile jarFileFactory;
 
 	static {
-		JarFile jf = null;
-
-		if (JVMInfo.JDK_ID >= 2) {
-			try {
-				Class jf2c = Class.forName("org.apache.derby.impl.services.reflect.JarFileJava2");
-				jf = (JarFile) jf2c.newInstance();
-			} catch (Exception e) {
-				throw new ExceptionInInitializerError(e);
-			}
-		} else {	
-			jf = new JarFile();
-		}
 
-		jarFileFactory = jf;
+		// 
+		jarFileFactory = new JarFileJava2();
 	}
 
 	private UpdateLoader updateLoader;

Modified: incubator/derby/code/trunk/java/engine/org/apache/derby/impl/sql/compile/FromVTI.java
URL: http://svn.apache.org/viewcvs/incubator/derby/code/trunk/java/engine/org/apache/derby/impl/sql/compile/FromVTI.java?view=diff&r1=151051&r2=151052
==============================================================================
--- incubator/derby/code/trunk/java/engine/org/apache/derby/impl/sql/compile/FromVTI.java (original)
+++ incubator/derby/code/trunk/java/engine/org/apache/derby/impl/sql/compile/FromVTI.java Wed Feb  2 12:48:12 2005
@@ -536,10 +536,6 @@
 		}
 		else
 		{
-			if (JVMInfo.JDK_ID == 1)
-				throw StandardException.newException(SQLState.LANG_RW_VTI_JAVA11, 
-										getVTIName());
-
 			version2 = true;
 		}
 

Modified: incubator/derby/code/trunk/java/engine/org/apache/derby/jdbc/EmbedXAConnection.java
URL: http://svn.apache.org/viewcvs/incubator/derby/code/trunk/java/engine/org/apache/derby/jdbc/EmbedXAConnection.java?view=diff&r1=151051&r2=151052
==============================================================================
--- incubator/derby/code/trunk/java/engine/org/apache/derby/jdbc/EmbedXAConnection.java (original)
+++ incubator/derby/code/trunk/java/engine/org/apache/derby/jdbc/EmbedXAConnection.java Wed Feb  2 12:48:12 2005
@@ -36,6 +36,7 @@
 
 import org.apache.derby.iapi.reference.SQLState;
 import org.apache.derby.iapi.reference.JDBC30Translation;
+import org.apache.derby.iapi.services.info.JVMInfo;
 
 import java.sql.Connection;
 import java.sql.SQLException;
@@ -869,7 +870,7 @@
 		else
 			xae = new XAException(XAException.XAER_RMERR);
 
-		if (org.apache.derby.iapi.services.info.JVMInfo.JDK_ID >= 4)
+		if (JVMInfo.JDK_ID >= JVMInfo.J2SE_14)
 			xae.initCause(se);
 		return xae;
 	}

Modified: incubator/derby/code/trunk/java/engine/org/apache/derby/jdbc/ResourceAdapterImpl.java
URL: http://svn.apache.org/viewcvs/incubator/derby/code/trunk/java/engine/org/apache/derby/jdbc/ResourceAdapterImpl.java?view=diff&r1=151051&r2=151052
==============================================================================
--- incubator/derby/code/trunk/java/engine/org/apache/derby/jdbc/ResourceAdapterImpl.java (original)
+++ incubator/derby/code/trunk/java/engine/org/apache/derby/jdbc/ResourceAdapterImpl.java Wed Feb  2 12:48:12 2005
@@ -61,10 +61,6 @@
 	{
 		// we can only run on jdk1.2 or beyond with JTA and JAVA 20 extension
 		// loaded.
-		if (SanityManager.DEBUG) {
-			if (JVMInfo.JDK_ID < 2)
-				SanityManager.THROWASSERT("expected JDK ID to be 2 - is " + JVMInfo.JDK_ID);
-		}
 
 		connectionTable = new Hashtable();
 

Modified: incubator/derby/code/trunk/java/engine/org/apache/derby/loc/messages_en.properties
URL: http://svn.apache.org/viewcvs/incubator/derby/code/trunk/java/engine/org/apache/derby/loc/messages_en.properties?view=diff&r1=151051&r2=151052
==============================================================================
--- incubator/derby/code/trunk/java/engine/org/apache/derby/loc/messages_en.properties (original)
+++ incubator/derby/code/trunk/java/engine/org/apache/derby/loc/messages_en.properties Wed Feb  2 12:48:12 2005
@@ -503,7 +503,6 @@
 42X92=Column name ''{0}'' appears more than once in a constraint''s column list.
 42X93=Table ''{0}'' contains a constraint definition with column ''{1}'' which is not in the table.
 42Z93=Constraints ''{0}'' and ''{1}'' have same set of columns, which is not allowed.
-42Z96=Read-write VTIs are not supported in JDK 1.1/JDBC 1.2 environments: ''{0}''
 42Z9B=The external virtual table interface does not support blob or clob columns. ''{0}'' column ''{1}''.
 42Z9D=''{0}'' statements are not allowed in ''{1}'' triggers.
 42Z9E=Constraint ''{0}'' is not a {1} constraint.

Modified: incubator/derby/code/trunk/java/tools/org/apache/derby/impl/tools/sysinfo/Main.java
URL: http://svn.apache.org/viewcvs/incubator/derby/code/trunk/java/tools/org/apache/derby/impl/tools/sysinfo/Main.java?view=diff&r1=151051&r2=151052
==============================================================================
--- incubator/derby/code/trunk/java/tools/org/apache/derby/impl/tools/sysinfo/Main.java (original)
+++ incubator/derby/code/trunk/java/tools/org/apache/derby/impl/tools/sysinfo/Main.java Wed Feb  2 12:48:12 2005
@@ -187,6 +187,8 @@
 
   private static void reportCloudscape (java.io.PrintWriter localAW) {
 
+	  localAW.println("JRE - JDBC: " + org.apache.derby.iapi.services.info.JVMInfo.derbyVMLevel());
+
 	  String classpath;
 
 	  try {
@@ -259,6 +261,10 @@
 
     localAW.println (Main.getTextMessage ("SIF02.J",
                                                            getJavaProperty ("user.dir")));
+
+	localAW.println("java.specification.name: " + getJavaProperty("java.specification.name"));
+	localAW.println("java.specification.version: " + getJavaProperty("java.specification.version"));
+
 
   } // end of reportJavaInfo
 

Modified: incubator/derby/code/trunk/java/tools/org/apache/derby/tools/ij.java
URL: http://svn.apache.org/viewcvs/incubator/derby/code/trunk/java/tools/org/apache/derby/tools/ij.java?view=diff&r1=151051&r2=151052
==============================================================================
--- incubator/derby/code/trunk/java/tools/org/apache/derby/tools/ij.java (original)
+++ incubator/derby/code/trunk/java/tools/org/apache/derby/tools/ij.java Wed Feb  2 12:48:12 2005
@@ -51,7 +51,7 @@
 	   * load based on the same criteria that the JDBC driver
 	   * uses.
 	   */
-	  if (JVMInfo.JDK_ID == 2)
+	  if (JVMInfo.JDK_ID == JVMInfo.J2SE_13)
 	  {
 		  Main.main(args);
 	  }
--- incubator/derby/code/trunk/java/engine/org/apache/derby/iapi/services/info/JVMInfo.java (original)
+++ incubator/derby/code/trunk/java/engine/org/apache/derby/iapi/services/info/JVMInfo.java Wed Feb  2 12:48:12 2005
@@ -29,16 +29,23 @@
 	/**
 		The JVM's runtime environment.
 		<UL>
-		<LI> 1 - JDK 1.1
-		<LI> 2 - JDK 1.2, 1.3
-		<LI> 4 - JDK 1.4.0 or 1.4.1
-		<LI> 5 - JDK 1.4.2
-		<LI> 6 - JDK 1.5
+		<LI> 1 - not used was JDK 1.1
+		<LI> 2 - J2SE_13- JDK 1.2, 1.3
+		<LI> 4 - J2SE_14 - JDK 1.4.0 or 1.4.1
+		<LI> 5 - J2SE_142 - JDK 1.4.2
+		<LI> 6 - J2SE_15 - JDK 1.5
 		</UL>
 		@return The JVM's runtime environment.
 	*/
 	public static final int JDK_ID;
 
+	public static final int J2SE_13 = 2;
+	public static final int J2SE_14 = 4;
+	public static final int J2SE_142 = 5;
+	public static final int J2SE_15 = 6; // aka J2SE 5.0
+
+	public static final boolean J2ME;
+
 	/**
     JDBC Boolean type - Types.BIT in JDK1.1 & 1.2 & 1.3, Types.BOOLEAN in JDK1.4
 	*/
@@ -60,6 +67,16 @@
 		// version 1.3.
 		//
 		String javaVersion;
+		String javaSpec;
+		boolean isJ2ME;
+
+		try {
+			javaSpec = System.getProperty("java.specification.name");
+		} catch (SecurityException se) {
+			// some vms do not know about this property so they
+			// throw a security exception when access is restricted.
+			javaSpec = null;
+		}
 
 		try {
 			javaVersion = System.getProperty("java.specification.version", "1.3");
@@ -70,39 +87,57 @@
 			javaVersion = "1.3";
 		}
 
-		if (javaVersion.equals("1.2") || javaVersion.equals("1.3"))
-		{	
-			id = 2; //jdk1.3 is still Java2 platform with the same API
-		}
-		else if (javaVersion.equals("1.4"))
+		if (javaSpec != null && javaSpec.startsWith("J2ME"))
 		{
-			String vmVersion = System.getProperty("java.version", "1.4.0");
-
-			if (JVMInfo.vmCheck(vmVersion, "1.4.0") || JVMInfo.vmCheck(vmVersion, "1.4.1"))
-				id = 4;
-			else
-				id = 5;
+			// IBM's WCTME 5.7 returns these values for CDC 1.0 profiles.
+			// "J2ME Foundation Specification"
+			//
+
+			// Foundation 1.0 and Personal Profile 1.0 based
+			// upon CDC 1.0 which is JDK 1.3 based
+			id = J2SE_13;
+			isJ2ME = true;
 		}
-        else if (javaVersion.equals("1.5"))
-        {
-            id = 6;
-        }
 		else
 		{
-			// aussme our lowest support unless the java spec
-			// is greater than our highest level.
-			id = 2;
-
-			try {
-
-				if (Float.valueOf(javaVersion).floatValue() > 1.4f)
-					id = 5;
-			} catch (NumberFormatException nfe) {
+			// J2SE/J2EE
+			isJ2ME = false;
+
+			if (javaVersion.equals("1.2") || javaVersion.equals("1.3"))
+			{	
+				id = J2SE_13; //jdk1.3 is still Java2 platform with the same API
+			}
+			else if (javaVersion.equals("1.4"))
+			{
+				String vmVersion = System.getProperty("java.version", "1.4.0");
+
+				if (JVMInfo.vmCheck(vmVersion, "1.4.0") || JVMInfo.vmCheck(vmVersion, "1.4.1"))
+					id = J2SE_14;
+				else
+					id = J2SE_142;
+			}
+			else if (javaVersion.equals("1.5"))
+			{
+				id = J2SE_15;
+			}
+			else
+			{
+				// aussme our lowest support unless the java spec
+				// is greater than our highest level.
+				id = J2SE_13;
+
+				try {
+
+					if (Float.valueOf(javaVersion).floatValue() > 1.4f)
+						id = 5;
+				} catch (NumberFormatException nfe) {
+				}
 			}
 		}
 
 		JDK_ID = id;
-		JAVA_SQL_TYPES_BOOLEAN = (id >= 4) ?
+		J2ME = isJ2ME;
+		JAVA_SQL_TYPES_BOOLEAN = (isJ2ME || id >= J2SE_14) ?
 			org.apache.derby.iapi.reference.JDBC30Translation.SQL_TYPES_BOOLEAN :java.sql.Types.BIT;
 	}
 
@@ -113,5 +148,20 @@
 	private static boolean vmCheck(String vmVersion, String id)
 	{
 		return vmVersion.equals(id) || vmVersion.startsWith(id + "_");
+	}
+
+	/**
+		Return Derby's understanding of the virtual machine's environment.
+	*/
+	public static String derbyVMLevel()
+	{
+		switch (JDK_ID)
+		{
+		case J2SE_13: return J2ME ? "J2ME - JDBC for CDC/FP 1.0" : "J2SE 1.3 - JDBC 2.1";
+		case J2SE_14: return "J2SE 1.4 - JDBC 3.0";
+		case J2SE_142: return "J2SE 1.4.2 - JDBC 3.0";
+		case J2SE_15: return "J2SE 5.0 - JDBC 3.0";
+		default: return "?-?";
+		}
 	}
 }

Modified: incubator/derby/code/trunk/java/engine/org/apache/derby/iapi/types/SQLDecimal.java
URL: http://svn.apache.org/viewcvs/incubator/derby/code/trunk/java/engine/org/apache/derby/iapi/types/SQLDecimal.java?view=diff&r1=151051&r2=151052
==============================================================================